struct PendingImageRecord {
tag: Option<Tag>,
bounds: LayoutRect,
clip_rect: LayoutRect,
transform: FastLayoutTransform,
url: Option<ServoUrl>,
natural_width: Option<Au>,
natural_height: Option<Au>,
}Expand description
https://w3c.github.io/paint-timing/#pending-image-record Different struct from spec, but fulfulling the same purpose.
Fields
tag: Option<Tag>The image element this record belongs to. for https://w3c.github.io/paint-timing/#pending-image-record-element
bounds: LayoutRectThe image rect (adjusted for object-fit/object-position).
clip_rect: LayoutRectThe element’s content box.
transform: FastLayoutTransformCumulative transform to root space, computed at collection time.
url: Option<ServoUrl>The image URL. None for background images.
natural_width: Option<Au>Intrinsic width, used for upscaling normalization.
natural_height: Option<Au>Intrinsic height, used for upscaling normalization.