struct TextRecord {
tag: Tag,
border_boxes: Vec<LayoutRect>,
}Expand description
https://w3c.github.io/paint-timing/#sec-recording-paint-timing
Each Element has a set of owned text nodes, which is an ordered set of Text nodes, initially empty.
This struct corresponds to an Element for accumulating set of owned text nodes by nearest ancestor box fragment’s tag during display list building.
Fields
tag: TagThe tag of containing box fragment these texts belongs to.
border_boxes: Vec<LayoutRect>https://w3c.github.io/paint-timing/#set-of-owned-text-nodes Collection of border_boxes of all Text nodes accumulated