pub(crate) struct PaintTimingHandler {
lcp_size: f32,
lcp_candidate: Option<LCPCandidate>,
viewport_rect: LayoutRect,
lcp_candidate_updated: bool,
}Fields
lcp_size: f32The document’s largest contentful paint size
lcp_candidate: Option<LCPCandidate>The LCP candidate, it may be a image or text.
viewport_rect: LayoutRectThe rect of viewport.
lcp_candidate_updated: boolFlag to indicate if there is an update to LCP candidate.
This is used to avoid sending duplicate LCP candidates to Paint.
Implementations
Sourceimpl PaintTimingHandler
impl PaintTimingHandler
pub(crate) fn new(viewport_size: LayoutSize) -> Self
pub(crate) fn check_bounding_rect( &self, bounds: LayoutRect, clip_rect: LayoutRect, ) -> bool
fn calculate_intersection_rect( &self, bounds: LayoutRect, clip_rect: LayoutRect, transform: FastLayoutTransform, ) -> Rect<f32, CSSPixel>
pub(crate) fn update_lcp_candidate( &mut self, tag: Option<Tag>, bounds: LayoutRect, clip_rect: LayoutRect, transform: FastLayoutTransform, url: Option<ServoUrl>, )
pub(crate) fn did_lcp_candidate_update(&self) -> bool
pub(crate) fn unset_lcp_candidate_updated(&mut self)
pub(crate) fn largest_contentful_paint_candidate(&self) -> Option<LCPCandidate>